@@ -7,8 +7,8 @@ extern "C" {
 #include <GL/glut.h>
 #include <GL/glu.h>
 #include <math.h>
-#include <QGLViewer/vec.h>
-#include <QGLViewer/camera.h>
+#include <qglviewer-qt3/vec.h>
+#include <qglviewer-qt3/camera.h>
 #include <ui/mwgen.h>
 #include <ui/sbviewer.moc>
 #include <qfiledialog.h>
