@@ -2,9 +2,9 @@
 #ifndef __SEARCHHELPER_H
 #define __SEARCHHELPER_H
 
-#include <QGLViewer/vec.h>
-#include <QGLViewer/camera.h>
-#include <QGLViewer/qglviewer.h>
+#include <qglviewer-qt3/vec.h>
+#include <qglviewer-qt3/camera.h>
+#include <qglviewer-qt3/qglviewer.h>
 
 class SearchHelper {
   public:
